Package: lifecontingencies
Type: Package
Title: Financial and Actuarial Mathematics for Life Contingencies
Version: 1.5.2
Authors@R: c(person("Giorgio Alfredo", "Spedicato", role = c("aut", "cre"),
    email = "spedicato_giorgio@yahoo.it",comment = c(ORCID = "0000-0002-0315-8888")),
    person("Christophe", "Dutang", role = "ctb",comment = c(ORCID = "0000-0001-6732-1501")),
    person("Reinhold", "Kainhofer", role = "ctb",comment = c(ORCID = "0000-0002-7895-1311")),
    person("Kevin J", "Owens", role = "ctb"),
    person("Ernesto", "Schirmacher", role = "ctb"),
    person("Gian Paolo", "Clemente", role = "ctb",comment = c(ORCID = "0000-0001-6795-4595")),
    person("Ivan", "Williams", role = "ctb")
    )
Maintainer: Giorgio Alfredo Spedicato <spedicato_giorgio@yahoo.it>
Description: Classes and methods that allow the user to manage life table,
    actuarial tables (also multiple decrements tables). Moreover, functions to easily
    perform demographic, financial and actuarial mathematics on life contingencies
    insurances calculations are contained therein. See Spedicato (2013)	<doi:10.18637/jss.v055.i10>.
Depends: R (>= 4.1.0), methods
Imports: parallel, utils, Rcpp (>= 1.0.0), stats
Suggests: demography, forecast, markovchain, testthat, knitr, formatR,
        StMoMo, rmarkdown
License: MIT + file LICENSE
Encoding: UTF-8
LazyLoad: yes
LazyData: true
BugReports: https://github.com/spedygiorgio/lifecontingencies/issues
BuildVignettes: yes
VignetteBuilder: utils, knitr
URL: https://github.com/spedygiorgio/lifecontingencies
LinkingTo: Rcpp
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-07-30 13:15:23 UTC; LEI00010
Author: Giorgio Alfredo Spedicato [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0315-8888>),
  Christophe Dutang [ctb] (ORCID:
    <https://orcid.org/0000-0001-6732-1501>),
  Reinhold Kainhofer [ctb] (ORCID:
    <https://orcid.org/0000-0002-7895-1311>),
  Kevin J Owens [ctb],
  Ernesto Schirmacher [ctb],
  Gian Paolo Clemente [ctb] (ORCID:
    <https://orcid.org/0000-0001-6795-4595>),
  Ivan Williams [ctb]
Repository: CRAN
Date/Publication: 2026-07-30 15:50:07 UTC
