# Generated by roxygen2: do not edit by hand

export(AExn)
export(Axn)
export(Axn.mdt)
export(Axyn)
export(Axyzn)
export(DAxn)
export(Exn)
export(IAxn)
export(Iaxn)
export(Isn)
export(Lxt)
export(Tx)
export(accumulatedValue)
export(annuity)
export(axn)
export(axyn)
export(axyzn)
export(convertible2Effective)
export(convexity)
export(decreasingAnnuity)
export(discount2Interest)
export(duration)
export(dxt)
export(effective2Convertible)
export(exn)
export(exyt)
export(exyzt)
export(getDecrements)
export(getLifecontingencyPv)
export(getLifecontingencyPvXyz)
export(getOmega)
export(head)
export(increasingAnnuity)
export(intensity2Interest)
export(interest2Discount)
export(interest2Intensity)
export(mx2qx)
export(mxt)
export(nominal2Real)
export(plot)
export(presentValue)
export(print)
export(probs2lifetable)
export(pxt)
export(pxyt)
export(pxyzt)
export(qx2mx)
export(qxt)
export(qxt.fromQxprime)
export(qxt.prime.fromMdt)
export(qxyt)
export(qxyzt)
export(rLife)
export(rLifeContingencies)
export(rLifeContingenciesXyz)
export(rLifexyz)
export(real2Nominal)
export(rmdt)
export(summary)
export(tail)
exportClasses(actuarialtable)
exportClasses(lifetable)
exportMethods(coerce)
exportMethods(getOmega)
exportMethods(plot)
exportMethods(print)
exportMethods(show)
exportMethods(summary)
import(methods)
import(parallel)
import(utils)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(stats,complete.cases)
importFrom(stats,integrate)
importFrom(stats,rbinom)
useDynLib(lifecontingencies, .registration = TRUE)
