# The lifecontingencies package

Classes and methods for managing life tables (for single and multiple decrements) and actuarial tables. Moreover, functions to easily perform demographic, financial and actuarial mathematics on life contingencies insurances calculations are contained therein.

## Install the current release from CRAN:
```r
install.packages('lifecontingencies')
```

## Install the development version from GitHub:
```r
devtools::install_github('spedygiorgio/lifecontingencies')
```

![alt tag](https://travis-ci.org/spedygiorgio/lifecontingencies.svg?branch=master)
[![Downloads](http://cranlogs.r-pkg.org/badges/lifecontingencies)](https://cran.r-project.org/package=lifecontingencies)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/lifecontingencies)](https://cran.r-project.org/package=lifecontingencies)
[![Research software impact](http://depsy.org/api/package/cran/lifecontingencies/badge.svg)](http://depsy.org/package/r/lifecontingencies)
[![R-CMD-check](https://github.com/spedygiorgio/lifecontingencies/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/spedygiorgio/lifecontingencies/actions/workflows/R-CMD-check.yaml)

