# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.mult3sum <- function(x, y, z) {
    .Call(`_lifecontingencies_mult3sum`, x, y, z)
}

.mult2sum <- function(x, y) {
    .Call(`_lifecontingencies_mult2sum`, x, y)
}

.presentValueC <- function(cashFlows, timeIds, interestRates, probabilities, power = 1.0) {
    .Call(`_lifecontingencies_presentValueC`, cashFlows, timeIds, interestRates, probabilities, power)
}

.fExnCpp <- function(T, y, n, i) {
    .Call(`_lifecontingencies_fExnCpp`, T, y, n, i)
}

.fAxnCpp <- function(T, y, n, i, m, k = 1) {
    .Call(`_lifecontingencies_fAxnCpp`, T, y, n, i, m, k)
}

.fIAxnCpp <- function(T, y, n, i, m, k = 1) {
    .Call(`_lifecontingencies_fIAxnCpp`, T, y, n, i, m, k)
}

.fDAxnCpp <- function(T, y, n, i, m, k = 1) {
    .Call(`_lifecontingencies_fDAxnCpp`, T, y, n, i, m, k)
}

.fAExnCpp <- function(T, y, n, i, k = 1) {
    .Call(`_lifecontingencies_fAExnCpp`, T, y, n, i, k)
}

